==> Pyrogram-0.12.0-py3-none-any.whl: pyrogram/api/types/update_user_pinned_message.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class UpdateUserPinnedMessage(Object):
    """Attributes:
        ID: ``0x4c43da18``

    Args:
        user_id: ``int`` ``32-bit``
        id: ``int`` ``32-bit``
    """

    __slots__ = ["user_id", "id"]

    ID = 0x4c43da18
    QUALNAME = "UpdateUserPinnedMessage"

    def __init__(self, *, user_id: int, id: int):
        self.user_id = user_id  # int
        self.id = id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "UpdateUserPinnedMessage":
        # No flags
        
        user_id = Int.read(b)
        
        id = Int.read(b)
        
        return UpdateUserPinnedMessage(user_id=user_id, id=id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.user_id))
        
        b.write(Int(self.id))
        
        return b.getvalue()

==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/types/update_user_pinned_message.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class UpdateUserPinnedMessage(Object):
    """Attributes:
        ID: ``0x4c43da18``

    Parameters:
        user_id: ``int`` ``32-bit``
        id: ``int`` ``32-bit``
    """

    __slots__ = ["user_id", "id"]

    ID = 0x4c43da18
    QUALNAME = "types.UpdateUserPinnedMessage"

    def __init__(self, *, user_id: int, id: int):
        self.user_id = user_id  # int
        self.id = id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "UpdateUserPinnedMessage":
        # No flags
        
        user_id = Int.read(b)
        
        id = Int.read(b)
        
        return UpdateUserPinnedMessage(user_id=user_id, id=id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.user_id))
        
        b.write(Int(self.id))
        
        return b.getvalue()
